<?php
/*
schreinerwissen. auftragsverwaltung 
Copyright (C) 2011  Carsten Hilbert
c-hilbert@web.de

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


/**
 * Class for creating html-elements like paragraph, cells etc.
 * 
 * @since 2010-07
 *
 */
class Html_Element 
{
    protected $condition;
    protected $th_td = 'td';
    protected $title;
    protected $i_zebra = 0;

/**
 * Formats a number
 * 
 * @param num $value
 * @param integer $behind
 * @return string formatted number 
 */  
function number_format($value, $behind=2) 
{
    // remove space
    $value2 = trim($value);

    // Check if is numeric value
    if (is_numeric($value2) ) {
        // change comma to dot
         #$value2 = str_replace(",", ".", $value2);
        return number_format($value2, $behind, ',', '.');
    }else{
        return $value;
    }
}


/**
 * Shows the text enclosed from the <tag>text</tag>
 * 
 * @param str $condition if displayed or not
 * @param mixed $content
 * @param str $tag tag wie z.b. p oder h1 oder h2
 */
function html_x( $condition, $content, $tag='', $style= '') 
{
    //$this->inhalt = $inhalt;
    //$this->bedingung = $bedingung;
    if (empty ($style)) {
        $style = '';
    }else{
        $style = ' style="'.$style.'"';
    }

    if ($tag != '') {
        $tag = $tag;
    }else{
        $tag = 'p';
    }
    $tag1 = '<' . $tag . $style . '>';
    $tag2 = '</' . $tag . '>';

    if ($condition) {
       $text = $content;
       return $tag1 . $text . $tag2;
    }
}


/**
 * Returns an input field for forms
 *
 * @param string $condition condition for display the field
 * @param string $in_type hidden or text
 * @param string $in_name
 * @param mixed $in_value
 * @param int $in_size
 * @param string $in_text
 * @param int $max_length
 * @return string
 */
function input($condition, $in_type, $in_name, $in_value, $in_size=4,
        $in_text='', $max_length=255)
{
    if($condition) {
        // when type is 'hidden' don't display size
        if($in_type == 'hidden') {
            $size2 = ''; 
        }else{
            $size2 = 'size="'.$in_size.'"';
        }
        if (empty($in_value) or $in_value == '0.00') {
            $in_value = '';
        }

        return "\n" . '<input type="' . $in_type . '" name="' . $in_name . '" value="'
        . $in_value . '" ' . $size2 . ' maxlength="' . $max_length . '" > ' 
        . $in_text  ;
    }
}


/**
 *
 * @param type $array_assoc_data
 * @return string 
 */
function make_hidden_input_from_array($array_assoc_data)
{
    $string = '';
    foreach ($array_assoc_data as $name => $value) {
        $string .= '<input type="hidden" name="' . $name . '" value="' . $value . '"  >';
        $string .= "\n";
    }
    return $string;
}

    
/**
 * Creates a checkbox, which transmits a value even when its unchecked
 * 
 * @param <string> $condition condition when the checkbox is displayed
 * @param <type> $name
 * @param <type> $in_text 
 */
function html_checkbox($condition, $name, $value, $in_text='')
{
    if($condition) {
        if ($value == 1) {
            $checked = 'checked';
        }else{
            $checked = '';
        }
        /**
         * Only the checked one will be transmitted, the hidden one transmit in
         * case of unchecked
         */
        $ch_box = '<input type="hidden" name="' . $name . '" value="0"/>' . "\n";
        $ch_box .= '<input type="checkbox" name="' . $name . '" value="1" '
                .  $checked . ' /> ' . $in_text;
        return $ch_box;
    }
}



/**
 * Creates a cell, wenn condition is true
 * 
 * @param str $condition 
 * @param str $content
 * @param str $ch_class
 * @param int $number_format 1=Zahl formatiert ausgeben
 * @param int $show_null 0= &nbsp;
 */
function tdh(   $condition, 
                $content, 
                $ch_class = '', 
                $number_format = 0,
                $show_null = 0 ) 
{
    $this->condition = $condition;

     if ($this->condition) {
        // remove space
        if ((empty($content) or $content == '0.00') and $show_null == 0) {
            $content = '&nbsp;';
        }

        if ($number_format == 1 ) {
            $content = $this->number_format($content);
        }

        print '<' . $this->th_td . ' ' .$ch_class . $this->title . '>';
        print $content;
        print '</' . $this->th_td . '>' . "\n";
    }  
}


/**
 * Sets a title for a html element
 * 
 * @param str $text Text wich will be displayed.
 */
public function set_title($text)
{
    $this->title = ' title="' . $text . '"';
}


/**
 * Clear title
 * 
 * @param str $text Text is empty
 */
public function drop_title()
{
    $this->title = '';
}


/**
 * Sets options for tdh 
 *
 * @param int $param  1=<th>, 2=<td>
 */
function set_th_td($param) 
{
    if ($param == 1) {
        $this->th_td = 'th';
    }elseif($param == 2) {
        $this->th_td = 'td';
    }
}


/**
 * This function must be setted instead of <tr> and color the background 
 * of the row alternate light and dark.
 * You must start the object before and beyond the loop.
 * 
 * @param str $field_delete field with deleted or not (1 or 0), in our case hide
 */
function set_tr_zebra($field_delete)
{
    // zebra
    if ($field_delete != 1) {
        if ($this->i_zebra == 0) {
            $class = ' class="row1"';
            $this->i_zebra = 1;
        }else    {
            $class = ' class="row2"';
            $this->i_zebra = 0;
        }
        
    // deleted records red
    }else{
        $class = 'class="bcolor2"';
    }
    print "<tr $class>";
}


function tr1($style='')
{
    print '<tr ' . $style . '>'. "\n";
}


function tr2()
{
    print "</tr>\n";
}


} // end class

?>